---
title: KG이니시스 채널설정방법
category: 결제서비스 (채널설정 및 이용안내) > 채널설정 > 채널설정
seo:
  title: KG이니시스 채널설정방법
  description: >-
    KG이니니스 연동을 위한 채널 설정 방법을 안내드립니다. '테스트 연동, 실 연동' 순으로 이뤄지며, 결제대행사와 연동방식별로 설정하는
    정보는 상이할 수 있습니다.
  keywords:
    - KG이니시스
    - 일반결제
    - 정기결제
    - 본인인증
    - 통합인증
    - 채널설정방법
tags:
  - KG이니시스
  - 결제
  - 본인인증
  - 채널설정방법
pgCompanies:
  - KG이니시스
searchTags:
  - 키파일
  - KG이니시스 일반
  - 이니시스 일반
  - 이니시스채널설정
  - 이니시스연동
  - 이니시스 일반결제
  - 이니시스 정기결제
  - 이니시스 본인인증
  - 이니시스 통합인증
  - KG이니시스 일반결제
  - KG이니시스 정기결제
  - KG이니시스 본인인증
  - KG이니시스 통합인증
  - KG이니시스 실연동
  - KG이니시스 실모드
  - KG이니시스
  - 이니시스 실연동
  - 이니시스 테스트연동
  - KG이니시스 테스트연동
  - KG이니시스 테스트모드
  - inicis
datetime: 2024-03-07T15:00:00.000Z
---

<Callout content="결제 연동을 위한 채널 설정 방법을 안내해 드립니다.
결제 연동을 위해서 채널설정은 필수이며 결제대행사와 연동방식별로 설정하는 정보는 상이할 수 있습니다.
또한 채널 설정 없이 결제 연동을 하실 경우 정상적인 호출이 불가하며, 오류가 발생됩니다." />

<Highlight url="#7_통합인증" text="KG이니시스 본인인증 통합인증 보러가기↓" />

<Highlight url="#13_결제창-일반/정기결제" text="KG이니시스 결제창 일반/정기결제 설정 보러가기↓" />

<Highlight url="#20_API-수기/정기결제-및-신용카드-본인인증" text="KG이니시스 API 수기/정기결제 및 신용카드 본인인증 설정 보러가기↓" />

<Callout content="[연동방식]
- 결제창 : 결제대행사(PG사)의 결제창을 띄워서 그 안에서 결제수단 선택 후 결제하는 방식
- API : 직접 구현한 UI를 통해 결제 수단 정보를 입력받아 API를 통해 결제하는 방식

[모듈버전]
- V1 : 포트원 결제모듈 V1. 다양한 결제대행사와 수단을 지원
- V2 : 포트원 차세대 결제 모듈로 직관적인 인터페이스를 지원
- 신모듈 : 결제대행사의 최신 버전의 모듈
- 구모듈 : 결제대행사의 구 버전의 모듈

[결제방식]
- 일반결제 : 구매자의 결제정보를 저장하지 않는 일회성 결제 (단건결제)
- 정기결제 : 구매자의 결제정보를 저장해놓고 재결제하는 결제 (정기 / 비 정기결제)" title="참고사항" icon="💡" />

## <Highlight text="결제창 일반/정기결제 및 API 수기/정기결제" />

- 포트원 결제모듈 V2에서만 지원됩니다.\
  별도의 키파일 등록 요청 없이 이니시스 관리자어드민에서 연동정보 확인 후 채널 추가가 가능합니다.

### **테스트 연동**

결제대행사와 계약 전에 미리 연동/개발이 가능한 테스트 연동환경입니다. 테스트 연동은 기본적인 결제 로직을 구현하실 수 있도록 미리 제공되는 범용적인 Key 입니다. 보다 자세한 테스트 연동 환경의 특징은 아래 가이드를 자세히 참조해주세요.

- [테스트 연동 특징 보러가기↗](https://help.portone.io/category/procedure/payment-integration/test?page=1)

<Callout icon="💡" title="참고사항" content="1. KG 이니시스 테스트모드의 경우, 실제 출금 되지만 **매일 23:00 ~ 23:50 사이 자동 취소 됩니다.**
2. 테스트환경에서는 결제창 내 카카오페이 및 네이버페이가 기본 노출되나, 실제로는 이니시스와 계약 시 서비스 이용을 신청하는 고객사에 한하여 서비스 이용이 가능합니다.
3. 국민카드의 경우 테스트결제 지원이 불가합니다. (국민카드 계열 포함 ex 카카오뱅크)" />



#### **설정경로**

- [포트원 관리자콘솔↗](https://admin.portone.io/) > 결제 연동 > 채널관리 > + 채널 추가
  - 연동 모드 : 테스트 연동
  - 결제대행사 : KG이니시스
  - 결제모듈 : 결제창 일반/정기결제 및 API 수기/정기결제

#### **설정방법**

- 채널 이름 : 상점 정보만으로는 채널(PG)의 성격을 파악하기 어려워 채널(PG)의 이름을 설정하는 용도로 구분하기 위한 필수 설정값으로 임의값으로 설정이 가능합니다(단, 숫자, 공백, 글자, \_, - 만 가능)
- 채널 속성 : 결제
- PG상점아이디 (MID) 클릭 \
  (KG이니시스 V2 테스트용 상점정보는 추후 제공될 예정)
  - 결제창 방식 / API 방식 정기결제용 : INIBillTst 선택
  - 결제창 방식 / API 방식 일반결제용 : INIpayTest 선택
- 과세설정 : [포트원 결제사정산 서비스↗ ](https://admin.portone.io/reconciliation/summary)이용시 단순 과세계산을 위해 사용되는 항목으로 미 이용시 설정하지 않으셔도 무방합니다. 거래의 과세/면세 여부와는 관계없습니다.

### **실 연동**

<Callout icon="💡" title="참고사항" content="발급된 상점 아이디의 카드사 심사가 이루어지지 않았을 경우 결제가 실패되오니 카드사 심사 완료 여부를 체크해주세요." />



#### **설정경로**

- [포트원 관리자콘솔↗](https://admin.portone.io/) > 결제 연동 > 채널관리 > + 채널 추가
  - 연동 모드 : 실 연동
  - 결제대행사 : KG이니시스
  - 결제모듈 : 결제창 일반/정기결제 ㅣ API 일반/정기결제

#### **설정방법**

- 채널 이름 : 상점 정보만으로는 채널(PG)의 성격을 파악하기 어려워 채널(PG)의 이름을 설정하는 용도로 구분하기 위한 필수 설정값으로 임의값으로 설정이 가능합니다(단, 숫자, 공백, 글자, \_, - 만 가능)
- 채널 속성 : 결제
- PG상점아이디 (MID) : KG이니시스로부터 받은 상점아이디를 입력합니다.
- 웹표준결제 signkey : [KG이니시스 상점관리자 페이지↗](https://iniweb.inicis.com/security/login.do) 접속 > 상점아이디로 로그인 > 상점정보 > 부가정보 > 웹 signkey 생성 조회 \[조회] 버튼 클릭

<Callout icon="💡" content="MID 별로 signkey가 상이하오니, 상점아이디는 반드시 **MOI**로 시작하는 올바른 MID로 로그인하여 확인해주시기 바랍니다." title="유의사항" />



- 과세설정 : [포트원 결제사정산 서비스↗ ](https://admin.portone.io/reconciliation/summary)이용시 단순 과세계산을 위해 사용되는 항목으로 미 이용시 설정하지 않으셔도 무방합니다. 거래의 과세/면세 여부와는 관계없습니다.
- INILite Key(정기결제) : [ KG이니시스 상점관리자페이지↗](https://iniweb.inicis.com) 접속 > 상점아이디로 로그인 > 상점정보 > 부가정보 > INILite Key 생성 갱신 \[조회] 클릭



<Callout title="V2 KG이니시스 개발가이드 보러가기↗" />

<Callout title="V1 KG이니시스 개발가이드 보러가기↗" />

## <Highlight text="통합인증" />

- 포트원 결제모듈 V1,V2 에서 지원됩니다.

### **테스트 연동**

결제대행사와 계약 전에 미리 연동/개발이 가능한 테스트 연동환경입니다. 테스트 연동은 기본적인 결제 로직을 구현하실 수 있도록 미리 제공되는 범용적인 Key 입니다. 보다 자세한 테스트 연동 환경의 특징은 아래 가이드를 자세히 참조해주세요.

- [테스트 연동 특징 보러가기↗](https://help.portone.io/category/procedure/payment-integration/test?page=1)

<Callout content="1. KG이니시스 통합본인인증서비스의 '카카오' 인증의 경우, CI값 제공 가능하나 이니시스와 계약시 별도 서류 작성 절차가 필요합니다.
2. 가입 신청 후, 이니시스 통합본인인증 계약 담당자를 통해 요청 주시기 바랍니다.
내국인/외국인 정보는 응답되지 않습니다.
" title="체크사항" icon="💡" />



#### **설정경로**

- [포트원 관리자콘솔↗](https://admin.portone.io/) > 결제 연동 > 채널관리 > + 채널 추가
  - 연동 모드 : 테스트 연동
  - 결제대행사 : KG이니시스
  - 결제모듈 : 본인인증 통합인증

#### **설정방법**

- 채널 이름 : 상점 정보만으로는 채널(PG)의 성격을 파악하기 어려워 채널(PG)의 이름을 설정하는 용도로 구분하기 위한 필수 설정값으로 임의값으로 설정이 가능합니다(단, 숫자, 공백, 글자, \_, - 만 가능)
- 채널 속성 : 본인인증
- PG상점아이디 (MID) 클릭 : 이니시스 통합인증 MIIiasTest 선택
- 과세설정 : [포트원 결제사정산 서비스↗](https://admin.portone.io/reconciliation/summary) 이용시 단순 과세계산을 위해 사용되는 항목으로 실제 거래의 과세/면세 여부와는 관계없으며 본인인증 채널의 경우 미설정으로 체크해주시기 바랍니다.

### **실 연동**

<Callout content="인증서를 제공하는 기관별로 심사가 진행되며 심사가 완료된 인증기관부터 차례로 인증창에 노출됩니다." title="체크사항" icon="💡" />



**설정경로**

- [포트원 관리자콘솔↗](https://admin.portone.io/) > 결제 연동 > 채널관리 > + 채널 추가
  - 연동 모드 : 실 연동
  - 결제대행사 : KG이니시스
  - 결제모듈 : 통합인증

#### **설정방법**

- 채널 이름 : 상점 정보만으로는 채널(PG)의 성격을 파악하기 어려워 채널(PG)의 이름을 설정하는 용도로 구분하기 위한 필수 설정값으로 임의값으로 설정이 가능합니다(단, 숫자, 공백, 글자, \_, - 만 가능)
- 채널 속성 : 통합인증
- PG상점아이디 (MID) : KG이니시스부터 발급받으신 상점아이디 ( MII 로 시작하는 코드 )
- apikey : KG이니시스부터 발급받으신 apikey
- 과세설정 : [포트원 결제사정산 서비스↗](https://admin.portone.io/reconciliation/summary) 이용시 단순 과세계산을 위해 사용되는 항목으로 실제 거래의 과세/면세 여부와는 관계없으며 본인인증 채널의 경우 미설정으로 체크해주시기 바랍니다.

<Callout title="V1 KG이니시스 통합인증 개발가이드 보러가기↗" />

<Callout title="V2 KG이니시스 통합인증 개발가이드 보러가기↗" />

## <Highlight text="결제창 일반/정기결제" />

- 포트원 결제모듈 V1에서만 지원됩니다.
- 결제창 일반 결제 및 정기결제를 위한 빌링키 발급이 가능합니다.

### **테스트 연동**

결제대행사와 계약 전에 미리 연동/개발이 가능한 테스트 연동환경입니다. 테스트 연동은 기본적인 결제 로직을 구현하실 수 있도록 미리 제공되는 범용적인 Key 입니다. 보다 자세한 테스트 연동 환경의 특징은 아래 가이드를 자세히 참조해주세요.

- [테스트 연동 특징 보러가기↗](https://help.portone.io/category/procedure/payment-integration/test?page=1)

<Callout icon="💡" title="참고사항" content="1. KG 이니시스 테스트모드의 경우, 실제 출금 되지만 **매일 23:00 ~ 23:50 사이 자동 취소 됩니다.**
2. 테스트환경에서는 결제창 내 카카오페이 및 네이버페이가 기본 노출되나, 실제로는 이니시스와 계약 시 서비스 이용을 신청하는 고객사에 한하여 서비스 이용이 가능합니다.
3. 국민카드의 경우 테스트결제 지원이 불가합니다. (국민카드 계열 포함 ex 카카오뱅크)" />



#### **설정경로**

- [포트원 관리자콘솔↗](https://admin.portone.io/) > 결제 연동 > 채널관리 > + 채널 추가
  - 연동 모드 : 실 연동
  - 결제대행사 : KG이니시스
  - 결제모듈 : 결제

#### **설정방법**

- 채널 이름 : 상점 정보만으로는 채널(PG)의 성격을 파악하기 어려워 채널(PG)의 이름을 설정하는 용도로 구분하기 위한 필수 설정값으로 임의값으로 설정이 가능합니다(단, 숫자, 공백, 글자, \_, - 만 가능)
- 채널 속성 : 결제
- PG상점아이디 (MID) 클릭
  - KG이니시스 결제창 일반결제 :  **INIpayTest** 선택
  - KG이니시스 결제창 정기결제 :  **INIBillTest** 선택

### **실 연동**

<Callout icon="💡" title="참고사항" content="1. 발급된 상점 아이디의 카드사 심사가 이루어지지 않았을 경우 결제가 실패되어니 카드사 심사 완료 여부를 체크해주세요.
2. **V1**으로 연동하는 경우 KG이니시스에서 MID와 키 파일(zip 파일)이 발급되며, **해당 키파일을 압축 상태 그대로 포트원 고객센터(cs@portone.io)를 통해 등록 요청하는 절차가 필요**합니다.   
**※ 포트원 서버 내 미등록시 일부 결제 · 환불시 오류가 발생됨**" />



#### **설정경로**

- [포트원 관리자콘솔↗](https://admin.portone.io/) > 결제 연동 > 채널관리 > + 채널 추가
  - 연동 모드 : 실 연동
  - 결제대행사 : KG이니시스
  - 결제모듈 : 결제창 일반/정기결제

#### **설정방법**

- 채널 이름 : 상점 정보만으로는 채널(PG)의 성격을 파악하기 어려워 채널(PG)의 이름을 설정하는 용도로 구분하기 위한 필수 설정값으로 임의값으로 설정이 가능합니다(단, 숫자, 공백, 글자, \_, - 만 가능)
- 채널 속성 : 결제
- PG상점아이디 (MID): KG이니시스로부터 받은 상점아이디를 입력합니다.
- 웹표준결제 signkey : [KG이니시스 상점관리자 페이지↗](https://iniweb.inicis.com/security/login.do) 접속 > 상점아이디로 로그인 > 상점정보 > 부가정보 > 웹 signkey 생성 조회 \[조회] 버튼 클릭

<Callout icon="💡" content="MID 별로 signkey가 상이하오니, 상점아이디는 반드시 **MOI**로 시작하는 올바른 MID로 로그인해주시기 바랍니다." title="유의사항" />



- INILite Key (일반결제) : **공란** (정기결제 시에만 설정되는 값입니다)
- INIAPI KEY, INIAPI IV : **공란**\
  ([이니시스 오픈마켓 영수증 api](https://developers.portone.io/api/rest-v1/partner#post%20%2Fpartners%2Freceipts%2F%7Bimp_uid%7D)를 사용하시는 경우에만 등록해주세요)

* INILite Key(정기결제) : [ KG이니시스 상점관리자페이지↗](https://iniweb.inicis.com) 접속 > 상점아이디로 로그인 > 상점정보 > 부가정보 > INILite Key 생성 갱신 \[조회] 클릭



<Callout title="V2 KG이니시스 개발가이드 보러가기↗" />

<Callout title="V1 KG이니시스 개발가이드 보러가기↗" />

## <Highlight text="API 수기/정기결제 및 신용카드 본인인증" />

- 포트원 결제모듈 V1에서만 지원됩니다.
- API 수기/정기결제 및 신용카드 본인인증 연동시 사용합니다.

### **테스트 연동**

결제대행사와 실 계약 전 미리 연동을 경험해 보실 수 있도록 테스트용 상점 정보를 제공합니다.\
KG이니시스의 테스트 연동은 일반 결제와 정기결제를 구분하여 설정할 수 있습니다.

- [테스트 연동 특징 보러가기↗](https://help.portone.io/category/procedure/payment-integration/test?page=1)

<Callout content="1. KG이니시스 테스트모드의 경우, 실제 출금 되지만 매일 23:00~23:50분 사이 자동 취소됩니다.
2. 국민카드의 경우 테스트결제 지원이 불가합니다. (국민카드 계열 포함 ex.카카오뱅크)" title="참고사항" icon="💡" />



#### **설정경로**

- [포트원 관리자콘솔↗](https://admin.portone.io/) > 결제 연동 > 채널관리 > + 채널 추가
  - 연동 모드 : 테스트 연동
  - 결제대행사 : KG이니시스
  - 결제모듈 : API 수기/정기결제

#### **설정방법**

- 채널 이름 : 상점 정보만으로는 채널(PG)의 성격을 파악하기 어려워 채널(PG)의 이름을 설정하는 용도로 구분하기 위한 필수 설정값으로 임의값으로 설정이 가능합니다. (단 숫자, 공백, 글자, `_`, `-`만 입력 가능)
- 채널 속성 : 결제
- PG상점아이디 (MID) 클릭
  - KG이니시스 API 정기결제 : INIBillTst 선택

<Callout content="KG이니시스 'API(폼페이) 방식'은 PG사를 통해 입점 가능 여부 확인이 우선적으로 필요합니다.
대부분의 경우 '결제창 방식'으로 지원되며, 'API 방식'은 PG사 정책으로 인하여 입점이 까다로운 점 참고 부탁드립니다." icon=" 💡 " title="유의사항" />

### **실 연동**

<Callout content="**발급된 상점 아이디의 카드사 심사가 이루어지지 않았을 경우 결제가 실패되오니 카드사 심사 완료 여부를 체크해 주세요!**
1. KG이니시스에서 MID와 키 파일(zip 파일)이 발급되며,해당 키파일을 압축 상태 그대로 포트원 고객센터(cs@portone.io)를 통해 등록 요청하는 절차가 필요합니다. (3영업 일 내 등록)
2. KG이니시스 'API( 폼페이) 방식'은 PG 사를 통해 입점 가능 여부 확인이 우선적으로 필요합니다.
대부분의 경우 '결제창 방식'으로 지원 가능하며 'API 방식'은 PG사 정책으로 인하여 입점이 까다로운 점 참고 부탁드립니다." title=" 체크사항" icon="💡" />



#### **설정경로**

- [포트원 관리자콘솔↗](https://admin.portone.io/) > 결제 연동 > 채널관리 > + 채널 추가
  - 연동 모드 : 테스트 연동
  - 결제대행사 : KG이니시스
  - 결제모듈 : API 수기결제

#### **설정방법**

- 채널 이름 : 상점 정보만으로는 채널(PG)의 성격을 파악하기 어려워 채널(PG)의 이름을 설정하는 용도로 구분하기 위한 필수 설정값으로 임의 값으로 설정이 가능합니다(단, 숫자, 공백, 글자, \_ , - 만 가능)
- 채널 속성 : 결제
- PG상점아이디 (MID): KG이니시스로부터 받은 상점아이디를 입력합니다.
- 웹표준결제 signkey : [KG이니시스 상점관리자 페이지↗](https://iniweb.inicis.com/security/login.do) 접속 > 상점아이디로 로그인 > 상점정보 > 부가정보 > 웹 signkey 생성 조회 \[조회] 버튼 클릭

<Callout icon="💡" content="MID 별로 signkey가 상이하오니, 상점아이디는 반드시 **MOI**로 시작하는 올바른 MID로 로그인해주시기 바랍니다." title="유의사항" />



- 과세설정 : [포트원 결제사정산 서비스↗ ](https://admin.portone.io/reconciliation/summary)이용시 단순 과세계산을 위해 사용되는 항목으로 미 이용시 설정하지 않으셔도 무방합니다. 거래의 과세/면세 여부와는 관계없습니다.

* INILite Key : [ KG이니시스 상점관리자페이지↗](https://iniweb.inicis.com) 접속 > 상점아이디로 로그인 > 상점정보 > 부가정보 > INILite Key 생성 갱신 \[조회] 클릭



<Callout title="V2 KG이니시스 개발가이드 보러가기↗" />

<Callout title="V1 KG이니시스 개발가이드 보러가기↗" />
